
.. blogpost::
    :title: Directly import from Github
    :keywords: github, import
    :date: 2016-01-05
    :categories: install, module

    If you want to do something like::

        from github_com.kennethreitz import requests
        assert requests.get('https://github.com').status_code == 200

    Just read the following blog post: `Import python modules straight from github <https://nvbn.github.io/2016/01/04/import-from-github/>`_.
